@@ -14,7 +14,7 @@ use List::Util      qw(any);
 use List::MoreUtils qw(uniq lastval);
 use Scalar::Util    qw(weaken);
 
-our $VERSION = '1.96';
+our $VERSION = '1.97';
 
 Travel::Status::DE::IRIS::Result->mk_ro_accessors(
 	qw(arrival arrival_delay arrival_has_realtime arrival_is_additional arrival_is_cancelled arrival_hidden
@@ -25,7 +25,7 @@ Travel::Status::DE::IRIS::Result->mk_ro_accessors(
 	  realtime_xml route_start route_end
 	  sched_arrival sched_departure sched_platform sched_route_start
 	  sched_route_end start
-	  station station_uic
+	  station station_eva station_uic
 	  stop_no time train_id train_no transfer type
 	  unknown_t unknown_o wing_id wing_of)
 );
@@ -939,7 +939,7 @@ arrival/departure received by Travel::Status::DE::IRIS
 
 =head1 VERSION
 
-version 1.96
+version 1.97
 
 =head1 DESCRIPTION
 
@@ -1284,7 +1284,7 @@ DateTime(3pm) object for the scheduled start of the train on its route
 
 Name of the station this train result belongs to.
 
-=item $result->station_uic
+=item $result->station_eva
 
 EVA number of the station this train result belongs to.
 This is often, but not always, identical with the UIC station number.
